@@ -1239,6 +1239,17 @@ class Bitbucket(AtlassianRestAPI):
         return self.delete(url)
 
     def get_diff(self, project, repository, path, hash_oldest, hash_newest):
+        """
+        Gets a diff of the changes available in the {@code from} commit but not in the {@code to} commit.
+        If either the {@code from} or {@code to} commit are not specified,
+        they will be replaced by the default branch of their containing repository.
+        :param project:
+        :param repository:
+        :param path:
+        :param hash_oldest: the source commit (can be a partial/full commit ID or qualified/unqualified ref name)
+        :param hash_newest: the target commit (can be a partial/full commit ID or qualified/unqualified ref name)
+        :return:
+        """
         if not self.cloud:
             url = 'rest/api/1.0/projects/{project}/repos/{repository}/compare/diff/{path}'.format(project=project,
                                                                                                   repository=repository,
@@ -1463,12 +1474,12 @@ class Bitbucket(AtlassianRestAPI):
             except_access_keys = []
         headers = self.default_headers
         if repository:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions".format(
                 project_key=project_key,
                 repository=repository
             )
         else:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/restrictions".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/restrictions".format(
                 project_key=project_key
             )
         if multiple_permissions:
@@ -1505,13 +1516,13 @@ class Bitbucket(AtlassianRestAPI):
         """
 
         if repository:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions/{id}".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions/{id}".format(
                 project_key=project_key,
                 repository=repository,
                 id=permission_id
             )
         else:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/restrictions/{id}".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/restrictions/{id}".format(
                 project_key=project_key,
                 id=permission_id
             )
@@ -1529,13 +1540,13 @@ class Bitbucket(AtlassianRestAPI):
         """
 
         if repository:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions/{id}".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/repos/{repository}/restrictions/{id}".format(
                 project_key=project_key,
                 repository=repository,
                 id=permission_id
             )
         else:
-            url = "/rest/branch-permissions/2.0/projects/{project_key}/restrictions/{id}".format(
+            url = "rest/branch-permissions/2.0/projects/{project_key}/restrictions/{id}".format(
                 project_key=project_key,
                 id=permission_id
             )
